Module file_stream

Module file_stream 

Structs

FileStream
A stream that iterates record batch by record batch, file over file.

Enums

OnError
Describes the behavior of the FileStream if file opening or scanning fails

Traits

FileOpener
Generic API for opening a file using an ObjectStore and resolving to a stream of RecordBatch

Type Aliases

FileOpenFuture
A fallible future that resolves to a stream of RecordBatch cbindgen:ignore