Structs
- File
Stream - A stream that iterates record batch by record batch, file over file.
Enums
- OnError
- Describes the behavior of the
FileStreamif file opening or scanning fails
Traits
- File
Opener - Generic API for opening a file using an
ObjectStoreand resolving to a stream ofRecordBatch
Type Aliases
- File
Open Future - A fallible future that resolves to a stream of
RecordBatchcbindgen:ignore