pub struct DefaultEngine<E: TaskExecutor> { /* private fields */ }Implementations
Sourceimpl DefaultEngine<TokioBackgroundExecutor>
impl DefaultEngine<TokioBackgroundExecutor>
Sourcepub fn builder(
object_store: Arc<DynObjectStore>,
) -> DefaultEngineBuilder<DefaultTaskExecutor>
pub fn builder( object_store: Arc<DynObjectStore>, ) -> DefaultEngineBuilder<DefaultTaskExecutor>
Create a DefaultEngineBuilder for constructing a DefaultEngine with custom options.
Parameters
object_store: The object store to use.
Sourceimpl<E: TaskExecutor> DefaultEngine<E>
impl<E: TaskExecutor> DefaultEngine<E>
Sourcepub fn enter(&self) -> <E as TaskExecutor>::Guard<'_>
pub fn enter(&self) -> <E as TaskExecutor>::Guard<'_>
Enter the runtime context of the executor associated with this engine.
Panics
When calling enter multiple times, the returned guards must be dropped in the reverse
order that they were acquired. Failure to do so will result in a panic and possible memory
leaks.
pub fn get_object_store_for_url( &self, _url: &Url, ) -> Option<Arc<DynObjectStore>>
Sourcepub fn default_parquet_handler(&self) -> Arc<DefaultParquetHandler<E>> ⓘ
pub fn default_parquet_handler(&self) -> Arc<DefaultParquetHandler<E>> ⓘ
Returns the concrete DefaultParquetHandler for callers that need the inherent
async write_parquet_file helper not exposed by the ParquetHandler trait.
For the metered trait surface used by reads, use Self::parquet_handler.
TODO(#2701): lift the inherent helper onto DefaultEngine so this accessor
(and the raw_parquet field) can be removed.
Sourcepub async fn write_parquet(
&self,
data: &ArrowEngineData,
write_context: &WriteContext,
) -> DeltaResult<Box<dyn EngineData>>
pub async fn write_parquet( &self, data: &ArrowEngineData, write_context: &WriteContext, ) -> DeltaResult<Box<dyn EngineData>>
Write data as a parquet file using the provided write_context.
data must not contain partition columns. If the table materializes partition columns (e.g.
materializePartitionColumns or icebergCompatV3), this function automatically inserts
them into the data.
The write_context must be created by Transaction::partitioned_write_context or
Transaction::unpartitioned_write_context, which handle partition value validation,
serialization, and logical-to-physical key translation.